summaryrefslogtreecommitdiffstats
path: root/akregator/src/tag.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tag.h')
-rw-r--r--akregator/src/tag.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/akregator/src/tag.h b/akregator/src/tag.h
index ebb3cf8e..01c0f4e2 100644
--- a/akregator/src/tag.h
+++ b/akregator/src/tag.h
@@ -25,7 +25,7 @@
#ifndef AKREGATOR_TAG_H
#define AKREGATOR_TAG_H
-#include <qstring.h>
+#include <tqstring.h>
namespace Akregator {
@@ -47,8 +47,8 @@ class Tag
public:
- /** creates a tag with given id, name and scheme. If name is QString::null, the id is used as name. If id is QString::null, the object is considered as NULL object (see isNull())*/
- Tag(const QString& id, const QString& name=QString::null, const QString& scheme=QString::null);
+ /** creates a tag with given id, name and scheme. If name is TQString::null, the id is used as name. If id is TQString::null, the object is considered as NULL object (see isNull())*/
+ Tag(const TQString& id, const TQString& name=TQString::null, const TQString& scheme=TQString::null);
/** creates a null tag (isNull() is @c true) */
Tag();
@@ -73,7 +73,7 @@ class Tag
The @c id is built using 'scheme + "/" + term': The example gets id = "http://del.icio.us/tag/foo"
@encode
*/
- static Tag fromCategory(const QString& term, const QString& scheme=QString::null, const QString& name=QString::null);
+ static Tag fromCategory(const TQString& term, const TQString& scheme=TQString::null, const TQString& name=TQString::null);
virtual ~Tag();
@@ -82,18 +82,18 @@ class Tag
bool isNull() const;
/** tag identifier, used as key throughout the app and archive. Must be unique in the tag set. Can be an arbitrary unicode string, an URI etc. */
- QString id() const;
+ TQString id() const;
/** user-visible name of the tag */
- QString name() const;
+ TQString name() const;
/** (optional) classfication scheme this tag belongs to */
- QString scheme() const;
+ TQString scheme() const;
- void setName(const QString& name);
+ void setName(const TQString& name);
- QString icon() const;
- void setIcon(const QString& icon);
+ TQString icon() const;
+ void setIcon(const TQString& icon);
Tag& operator=(const Tag& other);